.. _users-references:

References
==========

Studies describing pulse2percept:

.. [Beyeler2017] M Beyeler, GM Boynton, I Fine, A Rokem (2017). pulse2percept:
                 A Python-based simulation framework for bionic vision.
                 *Proceedings of the 16th Python in Science Conference*
                 *(SciPy)*, p.81-88, doi:`10.25080/shinma-7f4c6e7-00c
                 <https://doi.org/10.25080/shinma-7f4c6e7-00c>`_.

Studies referenced throughout the Documentation:

.. [Ahuja2008] AK Ahuja, MR Behrend, M Kuroda, MS Humayun, JD Weiland (2008).
               An in in vitro model of a retinal prosthesis.
               *IEEE Trans Biomed Eng* 55, 1744-1753.
.. [Beyeler2019] M Beyeler, D Nanduri, JD Weiland, A Rokem, GM Boynton, I Fine
                 (2019). A model of ganglion axon pathways accounts for
                 percepts elicited by retinal implants. *Scientific Reports*
                 9(1):9199, doi:`10.1038/s41598-019-45416-4
                 <https://doi.org/10.1038/s41598-019-45416-4>`_.
.. [Curcio1990] CA Curcio, KR Sloan, RE Kalina, AE Hendrickson (1990). Human
                photoreceptor topography.
                *Journal of Comparative Neurophysiology* 292:497-523,
                doi:`10.1002/cne.902920402
                <https://doi.org/10.1002/cne.902920402>`_.
.. [Granley2021] Granley, J., & Beyeler, M. (2021). A Computational Model of 
                 Phosphene Appearance for Epiretinal Prostheses. *International
                 Conference of the IEEE Engineering in Medicine and Biology
                 Society*.
.. [Greenwald2009] Greenwald, S., Horsager A., Humayun M, Greenberg R.,
                   McMahon M., Fine I. (2009).
                   Brightness as a Function of Current Amplitude in Human
                   Retinal Electrical Simulation. *Investigative Ophthalmology & Visual
                   Science November 2009* Vol.50, 5017-5025, doi:`10.1167/iovs.08-2897
                   <https://doi.org/10.1167/iovs.08-2897>`_.
.. [Hayes2003] JS Hayes et al. (2003). Visually guided performance of
               simple tasks using simulated prosthetic vision.
               *Artificial Organs* 27, 1016-1028.
.. [Horsager2009] A Horsager, SH Greenwald, JD Weiland, MS Humayun, RJ
                  Greenberg, MJ McMahon, GM Boynton, I Fine (2009). Predicting
                  visual sensitivity in retinal prosthesis patients.
                  *Investigative Ophthalmology & Visual Science*
                  50(4):1483-1491.
.. [Jansonius2009] NM Jansonius, J Nevalainen, B Selig, LM Zangwill, PA Sample,
                   WM Budde, JB Jonas, WA Lagreze, PJ Airaksinen, R Vonthein,
                   LA Levin, J Paetzold, U Schiefer (2009). A mathematical
                   description of nerve fiber bundle trajectories and their
                   variability in the human retina. *Vision Research* 49(17),
                   2157-63, doi:`10.1016/j.visres.2009.04.029
                   <https://doi.org/10.1016/j.visres.2009.04.029>`_.
.. [Layton2014] LN Ayton, PJ Blamey, RH Guymer, CD Luu, DAX Nayagam,
                NC Sinclair, MN Shivdasani, J Yeoh, MF McCombe, RJ Briggs,
                NL Opie, J Villalobos, PN Dimitrov, M Varsamidis, MA Petoe,
                CD McCarthy, JG Walker, N Barnes, AN Burkitt, CE Williams,
                RK Shepherd, PJ Allen, for the Bionic Vision Australia
                Research Consortium (2014). First-in-human trial of a novel
                suprachoroidal retinal prosthesis. *PLoS ONE*  9(12): e115239.
.. [Lorach2015] H Lorach, G Goetz, R Smith, X Lei, Y Mandel, T Kamins,
                K Mathieson, P Huie, J Harris, A Sher, D Palanker (2015).
                Photovoltaic restoration of sight with high visual acuity.
                *Nature Medicine* 21(5):476-482
.. [Nanduri2012] D Nanduri, I Fine, A Horsager, GM Boynton, MS Humayun,
                 RJ Greenberg, JD Weiland (2012), Frequency and amplitude
                 modulation have different effects on the percepts elicited
                 by retinal stimulation. Investigative Ophthalmology & Visual
                 Science 53:205-214, doi:`10.1167/iovs.11-8401
                 <https://doi.org/10.1167/iovs.11-8401>`_.
.. [Palanker2020] D Palanker, Y LeMer, S Mohand-Said, M Muqit, JA Sahel (2020).
                  Photovoltaic restoration of central vision in atrophic
                  age-related macular degeneration. *Ophthalmology* 1-8
.. [PerezFornos2012] A Perez Fornos, J Sommerhalder, L da Cruz, J Alain Sahel,
                     S Mohand-Said, F Hafezi, M Pelizzone (2012). Temporal Properties of
                     Visual Perception on Electrical Stimulation of the Retina.
                     *Investigative Ophthalmology & Visual Science*, doi: `10.1167/iovs.11-9344
                     <https://doi.org/10.1167/iovs.11-9344>`_.
.. [Petoe2021] MA Petoe, SA Titchener, M Kolic, WG Kentler, CJ Abbott, DAX Nayagam, 
               EK Baglin, J Kvansakul, N Barnes, JG Walker, SB Epp, KA Young, LN Ayton, 
               CD Luu, PJ Allen (2021). A Second-Generation (44-Channel) Suprachoroidal 
               Retinal Prosthesis: Interim Clinical Trial Results.
               *Translational Vision Science & Technology*, doi: `10.1167/tvst.10.10.12 
               <https://doi.org/10.1167/tvst.10.10.12>`_.
.. [Stingl2013] K Stingl, KU Bartz-Schmidt, D Besch, A Braun, A Bruckmann,
                F Gekeler, U Greppmaier, S Hipp, G Hortdorfer, C Kernstock,
                A Koitschev, A Kusnyerik, H Sachs, A Schatz, KT Stingl,
                T Peters, B Wilhelm, E Zrenner (2013). Artificial vision with
                wirelessly powered subretinal electronic implant alpha-IMS.
                *Proc R Soc B 280:20130077*.
.. [Stingl2017] K Stingl, R Schippert, KU Bartz-Schmidt, D Besch, CL Cottriall,
                TL Edwards, F Gekeler, U Greppmaier, K Kiel, A Koitschev,
                L Kuhlewein, RE MacLaren, JD Ramsden, J Roider, A Rothermel,
                H Sachs, GS Schroder, J Tode, N Troelenberg, E Zrenner (2017).
                Interim results of a multicenter trial with the new electronic
                subretinal implant Alpha AMS in 15 patients blind from
                inherited retinal degenerations. *Frontiers in Neuroscience*
                11:445.
.. [Thompson2003] RW Thompson Jr, GD Barnett, MS Humayun, G Dagnelie
                  (2003). Facial recognition using simulated prosthetic
                  pixelized vision.
                  *Investigative Ophthalmolology & Visual Science* 44,
                  5035-5042.
.. [Watson2014] A.B. Watson (2014). A formula for human retinal ganglion cell
                receptive field density as a function of visual field
                location. *Journal of Vision* 14(7):1-17,
                doi:`10.1167/14.7.15 <https://doi.org/10.1167/14.7.15>`_.
.. [Weitz2015]  Weitz, A. C., Nanduri, D., Behrend, M. R., Gonzalez-Calle, A.,
                Greenberg, R. J., Humayun, M. S., ... & Weiland, J. D. (2015).
                Improving the spatial resolution of epiretinal implants by 
                increasing stimulus pulse duration. Science translational medicine,
                7(318), 318ra203-318ra203.
.. [WileyWebster1982] JD Wiley, JG Webster (1982). Analysis and control of the
                      current distribution under circular dispersive 
                      electrodes. *IEEE Transactions on Biomedical Engineering*
                      5, 381-385.
.. [Yue2020] L Yue, V Wuyyuru, A Gonzalez-Calle, JD Dorn, MS Humayun (2020).
             Retina–electrode interface properties and vision restoration by
             two generations of retinal prostheses in one patient—one in each
             eye. *Journal of Neural Engineering* 026020.
